NSLS-II Beamline GUI Framework
===============================

The NSLS-II Beamline GUI Framework (nbs-gui) provides a flexible and extensible Qt-based GUI framework for beamline control and monitoring at NSLS-II. It includes:

* Modular tab-based interface
* Real-time device monitoring
* Sample management
* Plan execution
* Mode-based device management

.. image:: _static/screenshots/gui_overview.png
   :alt: nbs-gui main interface
   :align: center

Getting Started
---------------

New to nbs-gui? Start here:

.. toctree::
   :maxdepth: 1

   getting_started
   configuration
   workflows

User Guide
----------

Learn how to use nbs-gui effectively:

Standard Tabs
~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   tabs/index

Advanced Features
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   mode_management

Developer Guide
---------------

Extend and customize nbs-gui:

.. toctree::
   :maxdepth: 1
   :caption: Development

   architecture


API Reference
-------------

Complete API documentation:

.. toctree::
   :maxdepth: 2
   :caption: API

   api

Development
-----------

This project is part of the `xraygui <https://github.com/xraygui>`_ organization on GitHub.
